import { Component, ContentChildren, ElementRef, QueryList } from '@angular/core';
import { FadeInOutAnimation, CarouselSlideAnimation } from '@mintplayer/ng-animations';
import { BehaviorSubject, Subject } from 'rxjs';
import { map, take, takeUntil } from 'rxjs/operators';
import { BsCarouselImageDirective } from '../carousel-image/carousel-image.directive';
import * as i0 from "@angular/core";
import * as i1 from "@angular/common";
export class BsCarouselComponent {
    constructor() {
        this.destroyed$ = new Subject();
        this.currentImageIndex$ = new BehaviorSubject(-1);
        this.currentImage$ = this.currentImageIndex$
            .pipe(map((index) => { var _a; return (_a = this.images.get(index)) !== null && _a !== void 0 ? _a : null; }))
            .pipe(takeUntil(this.destroyed$));
    }
    ngOnInit() { }
    ngOnDestroy() {
        this.destroyed$.next(true);
    }
    ngAfterContentInit() {
        if (this.images.length > 0) {
            this.currentImageIndex$.next(0);
        }
        else {
            this.currentImageIndex$.next(-1);
        }
    }
    previousImage() {
        this.currentImageIndex$
            .pipe(take(1))
            .subscribe((currentImageIndex) => {
            if (currentImageIndex === 0) {
                this.currentImageIndex$.next(this.images.length - 1);
            }
            else {
                this.currentImageIndex$.next(currentImageIndex - 1);
            }
        });
    }
    nextImage() {
        this.currentImageIndex$
            .pipe(take(1))
            .subscribe((currentImageIndex) => {
            if (currentImageIndex >= this.images.length - 1) {
                this.currentImageIndex$.next(0);
            }
            else {
                this.currentImageIndex$.next(currentImageIndex + 1);
            }
        });
    }
    setCurrentImage(index) {
        this.currentImageIndex$.next(index);
    }
}
BsCarouselComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.0", ngImport: i0, type: BsCarouselComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
BsCarouselComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.0", type: BsCarouselComponent, selector: "bs-carousel", queries: [{ propertyName: "images", predicate: BsCarouselImageDirective, read: ElementRef }], ngImport: i0, template: "<div class=\"carousel slide\">\n    <div class=\"carousel-indicators\">\n        <button *ngFor=\"let image of images; let i = index\" type=\"button\" (click)=\"setCurrentImage(i)\" data-bs-target\n            [class.active]=\"(currentImageIndex$ | async) === i\"\n            [attr.aria-current]=\"(currentImageIndex$ | async) === i ? true : null\"\n            [attr.aria-label]=\"'Slide ' + i\"></button>\n    </div>\n    <div class=\"carousel-inner\" [@carouselSlide]=\"currentImageIndex$ | async\">\n        <ng-container *ngFor=\"let image of images; let i = index\">\n            <!-- @fadeInOut -->\n            <div class=\"carousel-item\" [class.active]=\"true\" *ngIf=\"(currentImageIndex$ | async) === i\">\n                <img [src]=\"image.nativeElement.src\" class=\"d-block\" [attr.alt]=\"image.nativeElement.alt\" [class.w-100]=\"true\">\n            </div>\n        </ng-container>\n    </div>\n    <button class=\"carousel-control-prev\" type=\"button\" (click)=\"previousImage()\">\n        <span class=\"carousel-control-prev-icon\" aria-hidden=\"true\"></span>\n        <span class=\"visually-hidden\">Previous</span>\n    </button>\n    <button class=\"carousel-control-next\" type=\"button\" (click)=\"nextImage()\">\n        <span class=\"carousel-control-next-icon\" aria-hidden=\"true\"></span>\n        <span class=\"visually-hidden\">Next</span>\n    </button>\n</div>", styles: [""], directives: [{ type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], pipes: { "async": i1.AsyncPipe }, animations: [FadeInOutAnimation, CarouselSlideAnimation] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.0", ngImport: i0, type: BsCarouselComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'bs-carousel',
                    templateUrl: './carousel.component.html',
                    styleUrls: ['./carousel.component.scss'],
                    animations: [FadeInOutAnimation, CarouselSlideAnimation]
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { images: [{
                type: ContentChildren,
                args: [BsCarouselImageDirective, { read: ElementRef }]
            }] } });
//# sourceMappingURL=carousel.component.js.map